<template>
  <a-spin :spinning="confirmLoading">
    <j-form-container :disabled="formDisabled">
      <a-form-model ref="form" :model="model" :rules="validatorRules" slot="detail">
        <a-row>
          <a-col :span="24">
            <a-form-model-item label="机构编码" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="orgCode">
              <a-input v-model="model.orgCode" placeholder="系统自动生成" :disabled="true" ></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="机构/部门名称" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="departName">
              <a-input v-model="model.departName" placeholder="请输入机构/部门名称"  ></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="部门类型" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="departCategoryId">
              <a-select v-model="model.departCategoryId" required placeholder="请选择部门类型">
                <a-select-option v-for="item of departmentCategoryList" :value="item.id" :key="item.id">
                {{(item.code+"/"+item.name)}}
                </a-select-option>
              </a-select>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="备注" :labelCol="labelCol" :wrapperCol="wrapperCol" prop="memo">
              <a-input v-model="model.memo" placeholder="请输入备注"  ></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>
<script>
  import { httpAction, getAction } from '@/api/manage'
  import { validateDuplicateValue } from '@/utils/util'
import { putAction } from '../../../../api/manage'
  export default {
    name: 'DepartForm',
    components: {
    },
    props: {
      //表单禁用
      disabled: {
        type: Boolean,
        default: false,
        required: false
      },
      parentId:{
        type:String,
        default:'',
        required:false
      },
      enterpriseId:{
        type:String,
        default:'',
        required:false
      },
      version:{
        type:Number,
        required:false
      }
    },
    data () {
      return {
        codeRule:'mom_base_depart_code_rule',
        tempName:'',
        departmentCategoryList:[],
        model:{
        },
        labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },
        confirmLoading: false,
        validatorRules: {
          departName:[
            {required:true,message:'请输入部门名称'},
            { validator:this.validateName},
            {min:0,max:32,message:'长度超出最大限制，请缩减长度'}
          ],
          orgCode:[
            {required:true},
          ],
          memo:[
            {min:0,max:100,message:'长度超出最大限制，请缩减长度'}
          ],
          departCategoryId:[{required:true,message:'请选择部门类型'}]
        },
        url: {
          add: "/base/depart/add",
          edit: "/base/depart/edit",
          queryById: "/base/depart/queryById",
          ruleBaseURL:"/sys/fillRule/executeRuleByCode",
          check:"/base/depart/check",
          getDepartCategory:"/base/depart/getDepartCategory"
        }
      }
    },
    computed: {
      formDisabled(){
        return this.disabled
      },
    },
    created () {
       //备份model原始值
      this.modelDefault = JSON.parse(JSON.stringify(this.model));
      this.getDepartCategory();

    },
    methods: {
      add () {
        this.edit(this.modelDefault);
      },
      edit (record) {
        this.model = Object.assign({}, record);
        if(this.model.id){
          this.tempName=this.model.departName;
        }
        this.visible = true;
        console.log(this.parentId+"=="+this.version+"=="+this.enterpriseId)
        if(!this.model.id){
          var ruleCodeParam={
            parentId:this.parentId,
            version:this.version?this.version:1,
            enterpriseId:this.enterpriseId
          }
          console.log(ruleCodeParam)
          putAction(this.url.ruleBaseURL+"/"+this.codeRule,ruleCodeParam).then(res=>{
            this.model.orgCode=res.result;
          });
        }
      },
      submitForm () {
        const that = this;
        // 触发表单验证
        this.$refs.form.validate(valid => {
          if (valid) {
            that.confirmLoading = true;
            let httpurl = '';
            let method = '';
            if(!this.model.id){
              httpurl+=this.url.add;
              method = 'post';
              if(this.version){
                this.model.version = this.version;
              }
              else{
                this.model.version = 1;
              }
              this.model.versionStatus='0';
              this.model.enterpriseId = this.enterpriseId;
              this.model.parentId = this.parentId;
            }else{
              httpurl+=this.url.edit;
               method = 'put';
            }
            httpAction(httpurl,this.model,method).then((res)=>{
              if(res.success){
                that.$message.success(res.message);
                that.$emit('ok');
              }else{
                that.$message.warning(res.message);
              }
            }).finally(() => {
              this.$emit('reloadUi')
              that.confirmLoading = false;
            })
          }else{
            this.$emit("changeAddLoading")
          }     
         
        })
      },
      validateName(rule, value, callback){
        var params = {
        departName:value,
        version:this.version,
        parentId:this.parentId
      };
      getAction(this.url.check,params).then(res=>{
            if(res.result.length==0){
              callback();
            }
            else if(this.tempName==value){
              callback();
            }
            else{
              callback('部门名称重复，请重新输入');
            }
        })
      },
      clearInfo(){
        this.model.orgCode=''
        var ruleCodeParam={
            version:this.version,
            parentId:this.parentId,
            enterpriseId:this.enterpriseId
        }
        putAction(this.url.ruleBaseURL+"/"+this.codeRule,ruleCodeParam).then(res=>{
            this.model.orgCode=res.result;
            this.model.departName='';
            this.model.departCategoryId='';
            this.model.memo=''
        });
      },
      getDepartCategory(){
        getAction(this.url.getDepartCategory).then(res=>{
          if(res.success){
             this.departmentCategoryList = res.result;
          }
          else{
             this.$message.error(res.message);
          }
        })
      }
    }
  }
</script>